package com.ynet.life.credit.util;

import com.ynet.life.util.Base64;
import java.io.File;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.OpenOption;
import java.security.KeyFactory;
import java.security.KeyPair;
import java.security.KeyPairGenerator;
import java.security.NoSuchAlgorithmException;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.SecureRandom;
import java.security.spec.InvalidKeySpecException;
import java.security.spec.PKCS8EncodedKeySpec;
import java.security.spec.X509EncodedKeySpec;
import javax.crypto.Cipher;
import org.apache.commons.lang.ArrayUtils;

/* loaded from: com_ynet_life_credit_util.jar:com/ynet/life/credit/util/RsaUtils.class */
public class RsaUtils {
    private static final int DEFAULT_KEY_SIZE = 2048;
    private static final int MAX_ENCRYPT_BLOCK = 245;
    private static final int MAX_DECRYPT_BLOCK = 256;

    public static PublicKey getPublicKey(byte[] bytes) throws InvalidKeySpecException, NoSuchAlgorithmException {
        X509EncodedKeySpec spec = new X509EncodedKeySpec(Base64.decode(bytes));
        return KeyFactory.getInstance("RSA").generatePublic(spec);
    }

    public static PublicKey getPublicKey(String publicKey) throws InvalidKeySpecException, NoSuchAlgorithmException {
        byte[] bytes = Base64.decodeToByte(publicKey);
        X509EncodedKeySpec spec = new X509EncodedKeySpec(bytes);
        return KeyFactory.getInstance("RSA").generatePublic(spec);
    }

    public static PrivateKey getPrivateKey(byte[] bytes) throws NoSuchAlgorithmException, InvalidKeySpecException {
        PKCS8EncodedKeySpec spec = new PKCS8EncodedKeySpec(Base64.decode(bytes));
        return KeyFactory.getInstance("RSA").generatePrivate(spec);
    }

    public static PrivateKey getPrivateKey(String privateKey) throws NoSuchAlgorithmException, InvalidKeySpecException {
        byte[] bytes = Base64.decodeToByte(privateKey);
        PKCS8EncodedKeySpec spec = new PKCS8EncodedKeySpec(bytes);
        return KeyFactory.getInstance("RSA").generatePrivate(spec);
    }

    public static void generateKey() throws Exception {
        KeyPairGenerator keyPairGenerator = KeyPairGenerator.getInstance("RSA");
        keyPairGenerator.initialize(DEFAULT_KEY_SIZE);
        KeyPair keyPair = keyPairGenerator.genKeyPair();
        byte[] publicKeyBytes = keyPair.getPublic().getEncoded();
        System.out.println("Base64 publicKey:".concat(String.valueOf(publicKeyBytes)));
        String publicKey = Base64.encodeToString(publicKeyBytes);
        System.out.println("Base64 publicKey:".concat(String.valueOf(publicKey)));
        String privateKey = Base64.encodeToString(keyPair.getPrivate().getEncoded());
        System.out.println("Base64 privateKey:".concat(String.valueOf(privateKey)));
    }

    public static PublicKey getPublicKeyFromFile(String filename) throws Exception {
        return getPublicKey(readFile(filename));
    }

    public static PrivateKey getPrivateKeyFromFile(String filename) throws Exception {
        return getPrivateKey(readFile(filename));
    }

    public static void generateKey(String publicKeyFilename, String privateKeyFilename, String secret, int keySize) throws Exception {
        KeyPairGenerator keyPairGenerator = KeyPairGenerator.getInstance("RSA");
        SecureRandom secureRandom = new SecureRandom(secret.getBytes());
        keyPairGenerator.initialize(Math.max(keySize, DEFAULT_KEY_SIZE), secureRandom);
        KeyPair keyPair = keyPairGenerator.genKeyPair();
        byte[] publicKeyBytes = Base64.encode(keyPair.getPublic().getEncoded());
        writeFile(publicKeyFilename, publicKeyBytes);
        byte[] privateKeyBytes = Base64.encode(keyPair.getPrivate().getEncoded());
        writeFile(privateKeyFilename, privateKeyBytes);
    }

    private static byte[] readFile(String fileName) throws Exception {
        return Files.readAllBytes(new File(fileName).toPath());
    }

    private static void writeFile(String destPath, byte[] bytes) throws IOException {
        File dest = new File(destPath);
        if (!dest.exists()) {
            dest.createNewFile();
        }
        Files.write(dest.toPath(), bytes, new OpenOption[0]);
    }

    public static String decryptByPublicKey(String publicKey, String text) throws Exception {
        X509EncodedKeySpec x509EncodedKeySpec = new X509EncodedKeySpec(Base64.decodeToByte(publicKey));
        PublicKey publicKeyObj = KeyFactory.getInstance("RSA").generatePublic(x509EncodedKeySpec);
        Cipher cipher = Cipher.getInstance("RSA");
        cipher.init(2, publicKeyObj);
        byte[] result = cipher.doFinal(Base64.decodeToByte(text));
        return new String(result);
    }

    /* JADX WARN: Type inference failed for: r0v10, types: [java.lang.String, java.lang.Exception] */
    public static String encryptByPrivateKey(String privateKey, String text) {
        ?? encodeToString;
        try {
            PKCS8EncodedKeySpec pkcs8EncodedKeySpec = new PKCS8EncodedKeySpec(Base64.decodeToByte(privateKey));
            PrivateKey privateKeyObj = KeyFactory.getInstance("RSA").generatePrivate(pkcs8EncodedKeySpec);
            Cipher cipher = Cipher.getInstance("RSA");
            cipher.init(1, privateKeyObj);
            encodeToString = Base64.encodeToString(cipher.doFinal(text.getBytes()));
            return encodeToString;
        } catch (Exception e) {
            encodeToString.printStackTrace();
            return null;
        }
    }

    public static String decryptByPrivateKey(String privateKey, String text) throws Exception {
        PKCS8EncodedKeySpec pkcs8EncodedKeySpec5 = new PKCS8EncodedKeySpec(Base64.decodeToByte(privateKey));
        PrivateKey privateKeyObj = KeyFactory.getInstance("RSA").generatePrivate(pkcs8EncodedKeySpec5);
        Cipher cipher = Cipher.getInstance("RSA");
        cipher.init(2, privateKeyObj);
        byte[] result = cipher.doFinal(Base64.decodeToByte(text));
        return new String(result);
    }

    public static String encryptByPublicKey(String publicKey, String text) throws Exception {
        X509EncodedKeySpec x509EncodedKeySpec2 = new X509EncodedKeySpec(Base64.decodeToByte(publicKey));
        PublicKey publicKeyObj = KeyFactory.getInstance("RSA").generatePublic(x509EncodedKeySpec2);
        Cipher cipher = Cipher.getInstance("RSA");
        cipher.init(1, publicKeyObj);
        return Base64.encodeToString(cipher.doFinal(text.getBytes()));
    }

    public static String encryptByPublicKeyNew(String publicKey, String text) throws Exception {
        X509EncodedKeySpec x509EncodedKeySpec2 = new X509EncodedKeySpec(Base64.decodeToByte(publicKey));
        PublicKey publicKeyObj = KeyFactory.getInstance("RSA").generatePublic(x509EncodedKeySpec2);
        Cipher cipher = Cipher.getInstance("RSA");
        cipher.init(1, publicKeyObj);
        byte[] data = text.getBytes("UTF-8");
        byte[] enBytes = null;
        for (int i = 0; i < data.length; i += MAX_ENCRYPT_BLOCK) {
            int i2 = i;
            byte[] doFinal = cipher.doFinal(ArrayUtils.subarray(data, i2, i2 + MAX_ENCRYPT_BLOCK));
            enBytes = ArrayUtils.addAll(enBytes, doFinal);
        }
        return Base64.encodeToString(enBytes);
    }

    public static String decryptByPrivateKeyNew(String privateKey, String text) throws Exception {
        PKCS8EncodedKeySpec pkcs8EncodedKeySpec5 = new PKCS8EncodedKeySpec(Base64.decodeToByte(privateKey));
        PrivateKey privateKeyObj = KeyFactory.getInstance("RSA").generatePrivate(pkcs8EncodedKeySpec5);
        Cipher cipher = Cipher.getInstance("RSA");
        cipher.init(2, privateKeyObj);
        byte[] data = Base64.decodeToByte(text);
        StringBuilder sb = new StringBuilder();
        for (int i = 0; i < data.length; i += MAX_DECRYPT_BLOCK) {
            int i2 = i;
            byte[] doFinal = cipher.doFinal(ArrayUtils.subarray(data, i2, i2 + MAX_DECRYPT_BLOCK));
            sb.append(new String(doFinal));
        }
        return sb.toString();
    }
}
